/*
 *		DANS UN LIEU INCONNU
 *
 *	essai sur la vision interieur d'un batiment
 *	===========================================
 *
 *	les elements rudimentaires qui vont meubler
 *	l'espace interieur, et le rendre plus vrai.
 *
 */

/*    ======================================================    */

#declare QK_radius = 4.50;
#declare QK_haut   = 5.50;
#declare QK_rtube  = 0.06;

#declare Quadri_Kiosque_pilier = object
{
merge	{
	cylinder { 0, y*0.15, 0.30 }
	sphere   { 0, 0.30 scale <1, 0.666, 1> translate y*0.15 }
	cylinder { 0, y*QK_haut, QK_rtube }
	sphere   {    y*QK_haut, 0.12 }
	}
}

#declare Quadri_Kiosque_les_piliers = object
{
union	{
	object { Quadri_Kiosque_pilier translate -x*QK_radius	}
	object { Quadri_Kiosque_pilier translate  x*QK_radius	}
	object { Quadri_Kiosque_pilier translate -z*QK_radius	}
	object { Quadri_Kiosque_pilier translate  z*QK_radius	}
	}
texture { GRIS_BROTCH scale 0.09 }
}

#declare Quadri_Kiosque_les_barres = object
{
union	{
	#local H = QK_haut + 0.55;
	cylinder { <-QK_radius, QK_haut, 0>, <0, H, 0>, QK_rtube }
	cylinder { < QK_radius, QK_haut, 0>, <0, H, 0>, QK_rtube }
	cylinder { <0, QK_haut, -QK_radius>, <0, H, 0>, QK_rtube }
	cylinder { <0, QK_haut,  QK_radius>, <0, H, 0>, QK_rtube }
	sphere   { y*H, 0.16 }
	#undef H
	}
texture { GRIS_BROTCH scale 0.11 }
}

#declare Quadri_Kiosque = object
{
union	{
	object { Quadri_Kiosque_les_piliers }
	object { Quadri_Kiosque_les_barres }
	}
}


/*    ======================================================    */

//--- mushroom

#declare shroom = lathe
   {
    cubic_spline
    10
    < 0.0  ,  0.287761 >,
    < 0.0  ,  0.287761 >,
    < 0.110804  ,  0.270507 >,
    < 0.210494  ,  0.199574 >,
    < 0.203634  ,  0.142057 >,
    < 0.0925914  ,  0.13631 >,
    < 0.124224  ,  0.0251171 >,
    < 0.180055  ,  -0.00454055 >,
    < 0.000391543  ,  -0.0259348 >,
    < 0.000391543  ,  -0.0259348 >
    }

#declare Mushroom = object
{

lathe { shroom scale <4, 5.5, 4> }

texture {
// https://wiki.povray.org/content/Documentation:Tutorial_Section_3.3
	pigment {
		gradient y
		color_map {
			[0.00 color Red]
			[0.33 color Orange]
			[0.66 color Yellow]
			[1.00 color Red]
			}
		scale <1, 0.19, 1>
		#if (mod(clock, 24) > 11)
 		  translate y * (NormClock *  17.00)
		#else
 		  translate y * (NormClock *  -6.00)
		#end
		}					// end of pigment
	normal { bozo 5.35 scale 0.42  }
	finish { phong PHONG specular SPECULAR emission 0.40 }
	}						// end of texture
}

#declare Le_Champi = object
{
union	{
	object { Base_Champi 				}
	object { Mushroom  translate y*(H_base-0.02)	}
	}
}
/*    ======================================================    */

/*
 *	tentative de blobery mise au point fin 2023
 */
#declare SZBB = 0.75;		// taille du demi-cote

#local SZBB_r = SZBB*0.86;	// rayon des ouvertures

#declare BoiteBloub_a = object
{
#local Ep = 0.04;		// epaisseur parois
#local Si = SZBB - Ep;		// dimension interieur

difference {
	box { <-SZBB,  -SZBB, -SZBB>, <SZBB, SZBB, SZBB> }
	box { <-Si, -Si, -Si>,  <Si,  Si, Si> }
	cylinder { <-3, 0, 0>,  <3, 0, 0>, SZBB_r }
	cylinder { < 0, 0, -3>, <0, 0, 3>, SZBB_r }
	cylinder { <0, 0, 0>, <0, 3, 0>, SZBB_r }
	}
texture { TEINTE_BASIQUE scale 2.11 }
}

/*
 *	armature externe
 */
#declare Bloub_armature = object
{
#local Tc = 0.03000;			// taille petits cubes
#local Ta = Tc * 0.70;			// taille des barres
#local Ec = SZBB;

union	{
	/*
	 *	les huit coins du truc
	 */
	box { <-Tc, -Tc, -Tc>, <Tc, Tc, Tc> translate <-Ec, -Ec, -Ec> }
	box { <-Tc, -Tc, -Tc>, <Tc, Tc, Tc> translate < Ec, -Ec, -Ec> }
	box { <-Tc, -Tc, -Tc>, <Tc, Tc, Tc> translate <-Ec, -Ec,  Ec> }
	box { <-Tc, -Tc, -Tc>, <Tc, Tc, Tc> translate < Ec, -Ec,  Ec> }
	box { <-Tc, -Tc, -Tc>, <Tc, Tc, Tc> translate <-Ec,  Ec, -Ec> }
	box { <-Tc, -Tc, -Tc>, <Tc, Tc, Tc> translate < Ec,  Ec, -Ec> }
	box { <-Tc, -Tc, -Tc>, <Tc, Tc, Tc> translate <-Ec,  Ec,  Ec> }
	box { <-Tc, -Tc, -Tc>, <Tc, Tc, Tc> translate < Ec,  Ec,  Ec> }

	/*
	 * les aretes du truc
	 */
	box { <-Ta, -Ta, -SZBB>, <Ta, Ta, SZBB>  translate < SZBB,  SZBB, 0> }
	box { <-Ta, -Ta, -SZBB>, <Ta, Ta, SZBB>  translate <-SZBB,  SZBB, 0> }
	box { <-Ta, -Ta, -SZBB>, <Ta, Ta, SZBB>  translate < SZBB, -SZBB, 0> }
	box { <-Ta, -Ta, -SZBB>, <Ta, Ta, SZBB>  translate <-SZBB, -SZBB, 0> }

	box { <-SZBB, -Ta, -Ta>, <SZBB, Ta, Ta>  translate <0, -SZBB, -SZBB> }
	box { <-SZBB, -Ta, -Ta>, <SZBB, Ta, Ta>  translate <0,  SZBB, -SZBB> }
	box { <-SZBB, -Ta, -Ta>, <SZBB, Ta, Ta>  translate <0, -SZBB,  SZBB> }
	box { <-SZBB, -Ta, -Ta>, <SZBB, Ta, Ta>  translate <0,  SZBB,  SZBB> }

	box { <-Ta, -SZBB, -Ta>, <Ta, SZBB, Ta>  translate <-SZBB, 0, -SZBB> }
	box { <-Ta, -SZBB, -Ta>, <Ta, SZBB, Ta>  translate < SZBB, 0, -SZBB> }
	box { <-Ta, -SZBB, -Ta>, <Ta, SZBB, Ta>  translate <-SZBB, 0,  SZBB> }
	box { <-Ta, -SZBB, -Ta>, <Ta, SZBB, Ta>  translate < SZBB, 0,  SZBB> }
	}
// texture { CYAN_CRACRA scale 8+NormClock }
texture { T_Brass_4C }
}

/*
 *	bordure des decoupes circulaires
 */
#declare Bloub_border = object
{
#local EB2 = 0.035;
#local R2 = SZBB_r-0.06;
merge	{
	difference {
		cylinder { -y*EB2, y*EB2, SZBB_r }
		cylinder { -y*1.10, y*1.10, R2 }
		}
	torus { R2, EB2  }
	// torus { SZBB_r-0.02, EB2/2 scale <1, 0.5, 1> translate -y*EB2 }
	}
// texture { CYAN_CRACRA }
texture { T_Copper_3C }
}

#declare BoiteBloub_b = object
{
union	{
	object { BoiteBloub_a }
	object { Bloub_armature }

	#local TR = SZBB - 0.03;
	object { Bloub_border rotate  x*90  translate <0, 0, -TR> }
	object { Bloub_border rotate  x*270 translate <0, 0,  TR> }

	object { Bloub_border rotate z*90   translate <-TR, 0, 0> }
	object { Bloub_border rotate z*270  translate < TR, 0, 0> }

	object { Bloub_border 			translate y*TR }
	}
}

#declare AutreBloub = object
{
#local EB = 0.23 + 0.28 * abs(sin(NormClock*31.4159));
blob	{
	threshold 0.24
	sphere { 0, (SZBB/2)*1.38,		1 }

	#local X = EB * cos(NormClock*13);
	#local Z = EB * sin(NormClock*17);
	sphere { <X, 0, Z>, SZBB*0.37,		1 }
	#local Y = EB * cos(NormClock*27.9);
	#local Z = EB * sin(NormClock*28.1);
	sphere { <0, Y, Z>, SZBB*0.34,		1 }
	#local X = EB * cos(NormClock*37);
	#local Y = EB * sin(NormClock*38);
	sphere { <X, Y, 0>, SZBB*0.35,		1 }
	}
texture { ORANGE_FLASHY scale 1.2 }
}

#declare BoiteBloub = object
{
union	{
	object { BoiteBloub_b		}
	object { AutreBloub		}
	}
rotate <0.42, 0.50, 1>
translate y*SZBB 
}

#declare La_BoiteBloub = object
{
union	{
	object { BoiteBloub translate y*(H_stand)		}
	object { Support_Bois_0					}
	object { Lampe_Boule_avec_support translate <0.04, 0, 0.03> }
	}
}

/*    ======================================================    */



/*    ======================================================    */
/*
 *		Bon, il est 13:37 et c'est l'heure d'improviser
 *		un nouvel objet, mais j'ai pas d'inspiration...
 */
#declare Machine_O_Base = object
{
#local D = 0.50;
#local E = 0.08;
difference {
	box { <-D, 0, -D>, <D, E, D> }
	#local R2 = 0.04;
	cylinder { <-D, -1, -D>, <-D, 1, -D>, R2 }
	cylinder { < D, -1, -D>, < D, 1, -D>, R2 }
	cylinder { <-D, -1,  D>, <-D, 1,  D>, R2 }
	cylinder { < D, -1,  D>, < D, 1,  D>, R2 }
	}
texture {  MON_VERT_INDUS scale 0.444 }
#undef D
#undef E
}
#declare Machine_O_Colonne = object
{
cylinder { <0, 0, 0>, <0, 1.2, 0>, 0.035 }
texture {  T_Gold_4C scale 0.03 }
}
#declare Machine_Outil = object
{
union	{
	object { Machine_O_Base }
	object { Machine_O_Colonne translate <-0.34, 0, 0.37> }
	object { Machine_O_Colonne translate < 0.34, 0, 0.37> }
	}
}
#declare La_Machine_Outil = object
{
union	{
	object { Seconde_Base }
	object { Machine_Outil translate y*H_base }
	}
}
/*    ======================================================    */

	/* PLACEHOLDER */

/*    ======================================================    */
/*    un truc bizarre pour lequel il va falloir que je me
 *    penche sérieusement sur des subtilités de povray, comme
 *    le concept de 'media'
 */

#local EH = 0.28;		// écart en haut

#declare EncoreUnTruc_a = object
{
#local RR = 0.060;		// rayon du tube
#local H0  = 0.13;		// hauteur base des tubes

#local Ha  = 1.20 + 0.90*Cos_010(abs(sin(NormClock*16)));
#local Hb  = 1.10 + 0.95*Cos_010(abs(sin(NormClock*11)));
#local Hc  = 1.05 + 1.07*Cos_010(abs(sin(NormClock* 8)));
#local Hd  = 1.20 + 0.91*Cos_010(abs(sin(NormClock* 7)));


merge	{
	cone   { <0, H0, 0>, RR/2,   <0,   Ha,  EH>, RR   }
	sphere { <0,   Ha,  EH>, RR   }

	cone   { <0, H0, 0>, RR/2,   <0,   Hb, -EH>, RR   }
	sphere { <0,   Hb, -EH>, RR   }

	cone   { <0, H0, 0>, RR/2,   < EH, Hc,   0>, RR   }
	sphere { <EH,   Hc,   0>, RR   }

	cone   { <0, H0, 0>, RR/2,   <-EH, Hd,   0>, RR   }
	sphere { <-EH,   Hd,   0>, RR   }
	}
texture { Orange_Glass scale 3.11 }
}

#declare EncoreUnTruc_base = object
{
#local Hbase = 0.08;
merge {
	#local E1 = EH * 1.35;
	box { <-E1, 0, -E1>, <E1, Hbase, E1> }
	#local E2 = EH * 0.75;
	box { <-E2, 0, -E2>, <E2, Hbase*2, E2> }
	}
texture { Dark_Green_Glass }
}

#declare EncoreUnTruc_machin = object
{
union {
	object { EncoreUnTruc_a }
	object { EncoreUnTruc_base }
	}
}
#declare EncoreUnTruc = object
{
union	{
	#local E = 0.47; 
	object { EncoreUnTruc_machin              translate <-E, 0, -E> }
	object { EncoreUnTruc_machin rotate y*90  translate < E, 0, -E> }
	object { EncoreUnTruc_machin rotate y*180 translate <-E, 0,  E> }
	object { EncoreUnTruc_machin rotate y*270 translate < E, 0,  E> }
	light_source { < 0, 0.85, 0>
		color Gray20
		fade_distance   FADE_D*0.18
		fade_power      FADE_P*1.22 		}
	}
}

#declare Le_Encore_Un_Truc = object
{
union	{
	object { Base_Machins }
	object { EncoreUnTruc translate y*H_base }
	}
}
/*    ======================================================    */
/*
 *	new: Thu Feb 22 19:23:44 UTC 2024
 */

#declare SFE = 0.60;
#declare HFE = 0.85;

#declare Texture_Exemple = texture
{
pigment {
	checker  color Red, color Blue 
	scale 0.15
	warp	{
		cylindrical		// XXX spherical 
		orientation y 
		dist_exp 1 
 		}
	rotate <10, 360*NormClock, 10>
	}
finish	{ ambient 0.76 roughness .01 }
} 

#declare Forme_Exemple_boite = object
{
#local dFe = 0.07;
difference {
	box { <-SFE, 0, -SFE>, <SFE, HFE, SFE> }
	box { <-dFe, -1, -dFe>, <dFe, 2, dFe> translate <-SFE, 0, -SFE> }
	box { <-dFe, -1, -dFe>, <dFe, 2, dFe> translate < SFE, 0, -SFE> }
	box { <-dFe, -1, -dFe>, <dFe, 2, dFe> translate <-SFE, 0,  SFE> }
	box { <-dFe, -1, -dFe>, <dFe, 2, dFe> translate < SFE, 0,  SFE> }
	}
}

/*
 *	assemblage de la forme exemple
 */
#macro Forme_Exemple(surface)
object
{
merge	{
	merge {
		object { Forme_Exemple_boite }
		cylinder { <SFE, 0, SFE>, <SFE, HFE+0.43, SFE>, 0.20 }
		sphere { 0, 0.20 scale <1, 0.32, 1>
			translate <SFE, HFE+0.43, SFE> }
		texture { surface }
		}

	torus	{
		0.36, 0.12	texture { surface }
				rotate <26, clock*2.3333, 19> 
				translate <-0.2, HFE+0.37, -0.2>
		}
	}
}
#end

#declare Base_Forme_Exemple = object
{
box { <-0.70, 0, -0.70>, <0.70, 0.10, 0.70> }
texture {
	pigment { color Gray50 }
	finish { specular 0.76 }
	}
}

#declare Forme_Exemple_0 = object
{
union	{
	object { Base_Forme_Exemple }
	object { Forme_Exemple(CYAN_CRACRA) }
	}
}

#declare Forme_Exemple_1 = object
{
union	{
	object { Base_Forme_Exemple }
	object { Forme_Exemple(MON_BLEU_SOMBRE) }
	}
}

#declare Forme_Exemple_2 = object
{
union	{
	object { Base_Forme_Exemple }
	object { Forme_Exemple(TURQ_BOZO) }
	}
}

#declare Forme_Exemple_3 = object
{
union	{
	object { Base_Forme_Exemple }
	object { Forme_Exemple(ROSE_BIZARRE) }
	}
}

#declare Forme_Exemple_4 = object
{
union	{
	object { Base_Forme_Exemple }
	object { Forme_Exemple(ORANGE_FLASHY) }
	}
}

#declare Forme_Exemple_5 = object
{
union	{
	object { Base_Forme_Exemple }
	object { Forme_Exemple(MON_VERT_INDUS) }
	}
}

#declare Forme_Exemple_6 = object
{
union	{
	object { Base_Forme_Exemple }
	object { Forme_Exemple(MON_ROUGE_INDUS) }
	}
}

/*    ======================================================    */

#declare MegaBrotch = object
{
#local prevX = 0.0;
#local prevY = 0.0;
#local prevZ = 0.0;

union	{
	#for (foo, 1, 12)
	  #local Hv  = 0.08 + (foo * 0.19);
	  #local Clk = clock * foo * 2.222;
	  #local Ang = radians(Clk);
	  #local R   = foo / 11.65;
	  #local Dx  = R * sin(Ang);
	  #local Dz  = R * cos(Ang);
	  union {
	    cylinder { <prevX, prevY, prevZ>, <Dx, Hv, Dz>, 0.036 }
	    sphere { <Dx, Hv, Dz>, 0.055 }
	    texture { GRIS_BROTCH }
	    }
	  torus { R, 0.028 translate y*Hv pigment { color Red } }
	  #local prevX = Dx;
	  #local prevY = Hv;
	  #local prevZ = Dz;
	#end

	// la base du brotch
	union {
		sphere { <0, 0, 0>, 0.24 scale <1, 0.50, 1> }
		#local B = 0.60;
		box { <-B, 0, -B>, <B, 0.04, B> }
		texture { MON_VERT_INDUS }
		}
	}
}

#declare Le_MegaBrotch = object
{
union	{
	object { Base_Machins }
	object { MegaBrotch translate y*H_base }
	}
}

/*    ======================================================    */
/*    nouveau 4 octobre 2021 à TerreBlanque */

#declare Une_Pale = object
{
merge	{
	cylinder { <0, 0, 0>, <0.35, -0.08, 0>, 0.010 }
	sphere { 0, 0.058 scale <1.0, 2.98, 0.41>
				translate <0.35, -0.08, 0> }
	}
}

#declare Un_Rotor = object
{
union	{
	/* moyeu */
	cylinder { <0, -0.05, 0>, <0,  0.05, 0>, 0.050 }
	sphere { 0, 0.050 scale <1, 0.3, 1> translate y*0.05 }
	/* branches */
	#for (foo, 0, 360, 72)
	  object { Une_Pale rotate y*foo }
	#end
	/* axe */
	cylinder { <0, -0.78, 0>, <0,  0.05, 0>, 0.020 }

	texture {
        	pigment { rgb <0.70, 0.38, 0.58> }
        	finish { phong PHONG  specular SPECULAR  reflection 0.35 }
        	}

	}
scale 0.85			// wtf ?
}

#declare Axe_Roto = object
{
merge {
	cylinder { <0, -0.80, 0>, <0, 0.15, 0>, 0.05 }
	sphere { <0, 0.15, 0>, 0.09 }
	torus {  0.35, 0.02 scale <1, 2.26, 1> }
	}
texture {
	pigment { rgb <0.40, 0.40, 0.68> }
	finish { phong PHONG  specular SPECULAR }
	}
}

//		--------------------------------------------

#declare Pied_RotoMachine = object
{
union	{
	cylinder { <0, 0, 0>, <0, 0.065, 0>, 0.39 }
	cylinder { <0, 0, 0>, <0, 0.055, 0>, 0.44 }
	}
texture {
	pigment { rgb <0.40, 0.40, 0.59> }
	finish { phong PHONG  specular SPECULAR }
	}
translate -y * 0.80		// WTF ?
}

//		--------------------------------------------

#declare RotoMachine = object
{
union	{
#for (foo, 0, 8, 1)
	#local rot1 = clock * 2.5;
	#if (mod(foo, 2))
	  #local rot2 =  rot1;
	#else
	  #local rot2 = -rot1;
	#end
	object { 
		Un_Rotor
		rotate y*rot2		// mouvement rotulatoire
		rotate x*90		// basculer horizontal
		translate z*0.65	// ecarter de l'axe
		rotate y*(foo*45)	// mettre au bon angle
		}
#end
	object { Axe_Roto }
	object { Pied_RotoMachine }
	}
}

#declare La_RotoMachine = object
{
union	{
	object { Base_Machins }
	object { RotoMachine translate y*1.40 }
	object { Lampe_Expo rotate  y*90    translate < 1.31, 0, -1.25> }
	}
}

// ================================================

#declare Spirale_A = object
{
union	{
	#for (foo, 0, 1.0, 0.0025)
	  #declare Amp_xz = 0.2 + foo * 0.65;
	  #declare Angle = foo * 17.89;
	  #declare XS = 0.08 +(Amp_xz * sin(Angle));
	  #declare YS = Cos_01(foo) * 1.22;
	  #declare ZS = 0.08 +(Amp_xz * cos(Angle));
	  sphere {
		<XS, YS, ZS>, 0.015+(Cos_010(foo)*0.051)
		texture {
			#local V2 = NormClock * 6;
			#local bar = V2 - int(V2);

			#if(0)
			#debug concat("Spirale", 
				str(foo, 6, 3), " ",	
				str(bar, 6, 3), "\n")
			#end

			#if (abs(bar-foo) > 0.04)
			  pigment { color Gray50 }
			  #local Emission = 0;
			#else
			  pigment { color Orange }
			  #local Emission = 0.35;
			#end
			normal { granite 0.27 scale 0.31 }  /* XXX */
			finish { phong PHONG  specular SPECULAR
					emission Emission }
			}
		}
	#end
	}
#undef Emission
}

#declare Les_Spirales = object
{
union	{
	#local HS = 0.95;
	object { Spirale_A              translate y*HS }
	object { Spirale_A rotate y*120 translate y*HS }
	object { Spirale_A rotate y*240 translate y*HS }
	object { Base_Machins }
	}
}

/*    ======================================================    */
/*      nouveau 17 aout 2021 chez Fred Fermion                  */
/*	largement modifié en janvier 2023			*/

#declare S_pm = 0.55;		/* demi taille sur x/z */

#local PM_anneau = object
{
#local EA = 0.023;
merge {
	cylinder { <0, -EA, 0>, <0, EA, 0>, 0.095 }
	sphere { 0, 0.095 scale <1, 0.35, 1> translate  y*EA }
	sphere { 0, 0.095 scale <1, 0.35, 1> translate -y*EA }
	}
#undef EA
}

#declare Plateau_Mobile = object
{
/*		Partie mobile */
union	{
	box { <-S_pm, -0.015, -S_pm>, <S_pm, 0.015, S_pm> }

	object { PM_anneau translate < S_pm, 0,  S_pm> }
	object { PM_anneau translate <-S_pm, 0,  S_pm> }
	object { PM_anneau translate < S_pm, 0, -S_pm> }
	object { PM_anneau translate <-S_pm, 0, -S_pm> }
	}

texture {
	pigment { color Pink }
	normal { bumps 0.26 scale 0.19 }
	finish { phong PHONG specular SPECULAR }
	}
}

#declare Support_Plateau = object
{
/*		Partie fixe */
union	{
	#local S = S_pm + 0.12;
	box { <-S, 0, -S>, <S, 0.05, S> }
	#local h1 = -0.01;
	#local h2 =  0.95;
	#local dd =  0.05;
	#local sd =  0.45;
	cylinder { <-S_pm, h1, -S_pm>, <-S_pm, h2, -S_pm>, dd }
	sphere { 0, dd scale <1, sd, 1> translate <-S_pm, h2, -S_pm> }
	cylinder { < S_pm, h1, -S_pm>, < S_pm, h2, -S_pm>, dd }
	sphere { 0, dd scale <1, sd, 1> translate < S_pm, h2, -S_pm> }
	cylinder { <-S_pm, h1,  S_pm>, <-S_pm, h2,  S_pm>, dd }
	sphere { 0, dd scale <1, sd, 1> translate <-S_pm, h2,  S_pm> }
	cylinder { < S_pm, h1,  S_pm>, < S_pm, h2,  S_pm>, dd }
	sphere { 0, dd scale <1, sd, 1> translate < S_pm, h2,  S_pm> }
	#local h3 = h2 - 0.03;
	cylinder { <-S_pm, h3, -S_pm>, < S_pm, h3,  S_pm>, dd/2 }
	cylinder { <-S_pm, h3,  S_pm>, < S_pm, h3, -S_pm>, dd/2 }
	}

texture { MON_VERT_INDUS }
}

#declare Plateau_Oscillant = object
{
#local Steps = 42;		// was: 51

#local Hvalue = mod(clock, Steps) / Steps;
#local Ydelta = 0.13 + (0.65 * Cos_010(Hvalue));

union	{
	object { Plateau_Mobile translate y*Ydelta }
	object { Support_Plateau }
	}
}

#declare Le_Plateau_Oscillant = object
{
union	{
	object { Table_Stand }
	object { Plateau_Oscillant rotate 3*y translate y*H_stand }
	}
}
/*    ======================================================    */
/*
 *		WARNING !
 *	RENDERING TIME RIDICULOUSLY LONG
 */
#declare Tube_Verre = object
{
#local Rtv = 0.24;

difference {
	cylinder { <0, 0, 0>,  <0, 1.50, 0>,   Rtv }
	cylinder { <0, -1, 0>, <0, 1.56, 0>,   Rtv-0.06 }
	}
texture { Green_Glass }
// interior { I_Glass }
}

#declare Monture_Tube = object
{
difference {
	cylinder { <0, -0.03, 0>,<0, 0.04, 0>, Rtv*1.09 }
	cylinder { <0,  0   , 0>,<0, 0.12, 0>, Rtv*0.999999 }
	}
texture { T_Copper_3B scale 9.333 }
}

#declare Tube_Complet = object
{
union	{
	object { Tube_Verre }
	object { Monture_Tube }
	}
}

#declare Forme_Rotator = object
{
#local Hfr = 0.50;
#local Rfr = 0.03;
union	{
	sphere { <0, Hfr, 0>, Rfr }
	cylinder { <0, -Hfr, 0>, <0, Hfr, 0>, Rfr }
	sphere { <0, -Hfr, 0>, Rfr }
	}
texture {
	pigment { color Gray50 }
	finish { phong PHONG specular SPECULAR*2 }
	}
rotate x*10
translate y*0.75
}

#declare RotaTube = object
{
union	{
	object { Tube_Complet }
	object { Forme_Rotator rotate y*(clock*14.77) }
	}
}

#declare PentaTube_A = object
{
#local Rpt = 0.72;
union	{
	#for (foo, 0, 360, 72)
		#local dx = Rpt * sin(radians(foo));
		#local dz = Rpt * cos(radians(foo));
		object { RotaTube rotate y*foo translate <dx, 0, dz> }
	#end
	}
}

//		--------------------

#declare Barre_Support_PT = object
{
#local T = Rpt;
union	 {
	box { <-0.02, 0, 0>, <0.02, 0.08, T> }
	cylinder { <0, -0.02, T>, <0, 0.20, T>, 0.03 }
	}
}

#declare Support_PentaTube = object
{
union	{
	#for (foo, 0, 360, 72)
	  object { Barre_Support_PT rotate y*foo translate y*0.10 }
	#end
	cylinder { <0, 0, 0>, <0, 0.20, 0>, 0.06 }

	cone { <0, 0.03, 0>, 0.26, <0, 0.06, 0>, 0.08 }
	cylinder { <0, 0, 0>, <0, 0.03, 0>, 0.26 }
	// cylinder { <0, 0.90, 0>, <0, 0.93, 0>, 0.26 }

	}
texture { T_Copper_3C scale 9.333 }
}

#declare PentaTube = object
{
union	{
	object { PentaTube_A translate y*0.35 }
	object { Support_PentaTube  }
	}
}

#declare Le_PentaTube = object
{
union	{
	object { PentaTube translate y*H_base }
	object { Base_Machins }
	}
}

/*    ======================================================    */
// nouveau Tue 21 Sep 2021 09:11:39 PM CEST

#declare Le_Grand_Titre_lettres = object
{
union	{
	#local Epp = 0.06;

	text { ttf "Fonts/dotmatrx.ttf" , "Dans un", Epp, 0
			translate <0.0, 1.14, 0> }
	text { ttf "Fonts/dotmatrx.ttf", "lieu inconnu", Epp, 0
			translate <0.0, 0.15, 0> }
	}
texture {
	#if (mod(clock, 39) > 14)
	  pigment { color Red }
	  finish { phong 0.09 emission 0.94 }
	#else
	  pigment { color Gray10 }
	  finish { phong 0.79 emission 0.07 }
	#end
	}
}

#declare Le_Grand_Titre_fond = object
{
box { <-0.3, 0,  0.14>, <9.4, 2.10,  0.12> }
texture {
	pigment { color Gray30 }
	finish { phong PHONG specular SPECULAR }
	}
}

#declare Le_Grand_Titre = object
{
union	{
	object { Le_Grand_Titre_lettres }
	object { Le_Grand_Titre_fond }
	}
scale 1.25
}
/*    ======================================================    */

#declare Forme_Signature = object
{
difference {
	box { <0, 0, -0.03>, <3.2, 0.8, 0.03> }
	text	{ ttf "Fonts/FreeSansBold.ttf" "*tTh*" 0.40, 0
			translate <0.17, 0.1, -0.2> }
	}
translate -1.25*x
}

#declare Signature = object
{
object	{
	Forme_Signature
	texture { TURQ_BOZO rotate y*clock scale 3.61 }
	}
}

/*    ======================================================    */
/*
 *    trucs utilisés par "TextureLab" de decorations.inc
 */
#declare A = 0.165;
#declare HB = 1.05;
#declare Hs = HB / 2;

#macro Bidule_boite(TXA)
intersection {
	sphere { <0, Hs, 0>, 0.47 }
	difference {
		box { <-A, 0, -A>, <A, HB, A> }
		sphere { <0, Hs, 0>, A*1.9 }
		#local B = A + 0.10;
		#local C = 0.12;
		cylinder { <0, -0.1, -B>, <0, HB+0.1, -B>, C }
		cylinder { <0, -0.1,  B>, <0, HB+0.1,  A>, C }
		cylinder { <-B, -0.1, 0>, <-B, HB+0.1, 0>, C }
		cylinder { < B, -0.1, 0>, < B, HB+0.1, 0>, C }
		}
	}
texture { TXA }
#end

#macro Bidule_boule(TXB)
difference {
	sphere { <0, Hs, 0>, A*1.48 }
	#for (foo, 0, 360, 51.428571)
	  #local dx = A*1.49*sin(radians(foo));
	  #local dz = A*1.49*cos(radians(foo));
	  // sphere { <dx, Hs, dz>, A*0.54 scale <1, 2, 1> }
	  sphere { 0, A*0.36 scale <1, 2.6, 1> translate <dx, Hs, dz> }
	#end
	}
texture { TXB }
rotate y*(clock*5.5)
#end

#macro Un_Bidule(TXA, TXB)
union	{
	object { Bidule_boite(TXA) }
	object { Bidule_boule(TXB) }
	}
#end

/*    ======================================================    */

#declare Grille_Ronde = object
{
#local RGR = 0.84;
union	{
	torus { RGR, 0.02  translate y*0.20 }
	torus { RGR, 0.02  translate y*1.30 }
	#for (foo, 0, 360, 10)
		#local dx = RGR * sin(radians(foo));
		#local dz = RGR * cos(radians(foo));
		cylinder { <dx, 0.20, dz>, <dx, 1.30, dz>, 0.01 }
	#end
	#for (foo, 0, 360, 30)
		#local dx = RGR * sin(radians(foo));
		#local dz = RGR * cos(radians(foo));
		cylinder { <dx, 0.0, dz>, <dx, 0.20, dz>, 0.014 }
		cylinder { <dx, 0.0, dz>, <dx, 0.01, dz>, 0.031 }
	#end
	}
texture	{
	pigment { color Gray20 }
	normal { granite 0.10 scale 0.21 }
	finish { phong PHONG  specular SPECULAR }
	}
}

/*    ======================================================    */

#declare Machin_0_gelule = object
{
#local Rm0 = 0.49;
union {
	sphere { <0, 1, 0>, Rm0 }
	cylinder { <0, 1, 0>, <0, 2, 0>, Rm0 }
	sphere { <0, 2, 0>, Rm0 }
	}
texture { PinkAlabaster
		scale 0.110987 + Cos_010(NormClock)
		rotate <clock/2.0, clock/3.0, clock/4.0>
		}
}

#declare M0_barre = object
{
#local DX = 0.12;
#local H0 = 1.42;
merge	{
	box      { <-DX, 0, -0.025>, < DX, H0-0.10, 0.025> 	}
	cylinder { <-DX, 0, 0>,     <-DX, H0-0.10, 0>, DX*0.25 	}
	cylinder { < DX, 0, 0>,     < DX, H0-0.10, 0>, DX*0.25 	}
	cylinder { <0, H0-0.25, 0>, <0, H0-0.036, 0.253>, 0.026	}
	}
}

#declare Machin_0_support = object
{
merge	{
	cylinder { <0, 0, 0>, <0, 0.08, 0>, Rm0*1.58     }
	cylinder { <0, 0, 0>, <0, 0.10, 0>, Rm0*1.48     }
	#local d = Rm0 + 0.10;
	object { M0_barre              translate  d*z }
	object { M0_barre rotate 180*y translate -d*z }
	object { M0_barre rotate 270*y translate -d*x }
	object { M0_barre rotate  90*y translate  d*x }
	torus  { Rm0*1.74 0.037         translate  y*H0-0.05 }
	}
texture { T_Brass_2A scale 1.3 }
}

#declare Machin_0 = object
{
union {
	object { Machin_0_gelule  rotate -clock*y       }
	object { Machin_0_support rotate y*clock        }
	}
}

#declare Le_Machin_Gelule = object
{
union {
	object { Machin_0                translate y*H_base }
	object { Seconde_Base  }
	}
}

/*    ======================================================    */

#local Decoupe_m1 = object
{
#local rr = 0.09;
#local r2 = rr * 2.1;
merge	{
	cylinder { <0, -1, 0>,   <0, 5, 0>, rr	}
	cylinder { <0, -1, 0>, <0, 0.55, 0>, r2	}

	sphere { <0, 0, 0>, r2 scale <1.2, 1.6, 1.2>
				translate y*0.76	}
	sphere { <0, 0, 0>, r2 scale <2.5, 1.3, 2.5>
				translate y*2.10	}
	}
}

#declare Machin_1_a = object
{
#local d    = 0.49;
#local h    = 2.10;
#local h2   = h * 0.65;
difference {
	box { <-d, 0.05, -d>, <d, h, d> }
	#local r2 = d * 0.700;
	cylinder { <-2, h2,  0>, <2, h2, 0>, r2 }
	cylinder { < 0, h2, -2>, <0, h2, 2>, r2 }
	object { Decoupe_m1    translate <-d, 0, -d> }
	object { Decoupe_m1    translate < d, 0, -d> }
	object { Decoupe_m1    translate <-d, 0,  d> }
	object { Decoupe_m1    translate < d, 0,  d> }
	}
texture { Rosewood scale 0.55 }
}

#declare Machin_1_b = object
{
#declare e2 = d - 0.15;
#declare r3 = d * 0.504;
union	{
	cylinder { <-e2, h2,  0>, <e2, h2, 0>, r3 }
	sphere { 0, r3 translate <-e2, h2,  0> }
	sphere { 0, r3 translate < e2, h2,  0> }

	cylinder { < 0, h2, -e2>, <0, h2, e2>, r3 }
	sphere { 0, r3 translate < 0, h2, -e2> }
	sphere { 0, r3 translate < 0, h2,  e2> }
	}
texture { T_Wood32 scale 0.96  }
}

#declare Machin_1 = object
{
union {
	object { Machin_1_a  }
	object { Machin_1_b  }
	}
rotate y*40
}

#declare Le_Machin_en_bois = object
{
union	{
	object { Machin_1 translate y*H_base }
	object { Base_Machins }
	object { Lampe_Expo rotate y*5 translate <0.8, 0, 1.5> }
	}
}

/*    ======================================================    */
/*
 *	Une espece d'oeuf bizarre en pierre
 */
#declare Machin_2_a = object
{
difference {
	sphere { <0, 0, 0>, 0.50 scale <1, 2.75, 1>       }
	torus  { 0.55, 0.18      scale <1, 2.51, 1>    }
	}
texture {
	pigment { color Pink 				}
	normal  { dents 1.5 scale 0.1 			}
	finish  { phong PHONG  specular SPECULAR 	}
	}
}

#declare Machin_2_b = object
{
difference	{
	torus  { 0.58, 0.095 scale <1, 1.75, 1> }
	#for (foo, 0, 360, 30)
	  #local ra = 0.73;
	  #local dx=ra*sin(radians(foo));
	  #local dz=ra*cos(radians(foo));
	  sphere { <0, 0, 0>, 0.11 translate <dx, 0, dz> }
	#end
	}
texture {
	pigment { color DarkGreen }
	normal  { ripples 4.5 scale 0.22 }
	finish  { phong PHONG  specular SPECULAR }
	}
scale <1, 1.5, 1>
rotate	y*(clock*5.80)
}

#declare Fuseau_en_Pierre = object
{
union {
	object { Machin_2_a  }
	object { Machin_2_b  }
	}
translate y*1.42
}

#declare Le_Fuseau_en_Pierre = object
{
union {
	object { Fuseau_en_Pierre translate y*H_base }
	object { Base_Machins }
	}
}

/*    ======================================================    */
/*
 *	ici on pourrait experimenter sur le blob
 */
#declare Machin_3_a = object
{
merge	{
	sphere { <0, 0, 0>, 0.38 scale <1.0, 1.6, 1.3> translate y*0.13 }
	sphere { <0, 0, 0>, 0.27 scale <1.3, 1.6, 1.0> translate y*0.82 }
	sphere { <0, 0, 0>, 0.17 scale <1.3, 1.6, 1.0> translate y*1.32 }
	}
texture {
	pigment { color rgb <0.77, 0.50, 0.59> }
	normal {
		bumps 0.75 scale 0.175
		rotate <clock*3.3, clock*1.9, clock*2.5> } /* XXX lent ! */
	finish { phong PHONG specular SPECULAR }
	}
scale  <1, 0.90, 1>
rotate x*4    translate -0.05*z    rotate -(2.45*clock)*y
}
#declare Machin_3 = object
{
union {
	object { Machin_3_a  translate y*0.54 }
	object { Grille_Ronde }
	}
}

#declare Le_Machin_3 = object
{
union {
	object { Machin_3  translate y*H_base }
	object { Base_Machins }
	}
}

/*    ======================================================    */
/*
 *		le machin 4 est constitué de neuf barres
 *		dont la hauteur varie en suivant une 
 *		mystérieuse loi de Fourier.
 */

#local M4_da = 0.105;		// dimension d'une barre

#macro Machin_4_une_barre_a(Hauteur)
// {
#local db = M4_da * 0.99;
#local dc = M4_da * 1.09;
difference {
	box { <-M4_da, 0.10, -M4_da>, <M4_da, Hauteur-0.1, M4_da> }
	cylinder { <-dc, -1, -dc>, <-dc, Hauteur, -dc>, db }
	cylinder { < dc, -1, -dc>, < dc, Hauteur, -dc>, db }
	cylinder { <-dc, -1,  dc>, <-dc, Hauteur,  dc>, db }
	cylinder { < dc, -1,  dc>, < dc, Hauteur,  dc>, db }
	}
texture {
	pigment { color srgb <0.42, 0.52, 0.37> }
	normal  { dents 3.14159 rotate 48*x scale 0.16*Hauteur }
	finish { phong PHONG specular SPECULAR }
	}
rotate y*20
// }
#end

// ----------------------------------------------------------
#macro Machin_4_une_barre_b(Hauteur)
// {
#local Db = M4_da * 0.45;
#local Dh = Hauteur * 0.95;
#local De = 0.07;
merge {
	cylinder { <-De, 0.10, 0>, <-De, Dh, 0>, Db }
	cylinder { < De, 0.10, 0>, < De, Dh, 0>, Db }
	}
texture {
	pigment { color srgb <0.90, 0.08, 0.05> }
	normal  { bozo 1.8 scale 0.51 }
	finish { phong PHONG specular SPECULAR }
	}
rotate y*(Hauteur*110)
// }
#end

// ----------------------------------------------------------
/* 	le genre de plateau sous les barres */

#declare Machin_4_a = object
{
#local Dim  = 0.89;
#local Di2  = Dim - 0.05;
difference {
	box { <-Dim, 0.01, -Dim>, <Dim, 0.09, Dim> }
	box { <-Di2, 0.08, -Di2>, <Di2, 0.10, Di2> }
	}	
texture {
	pigment { color srgb <0.29, 0.42, 0.29> }
	normal  { dents 2.8 rotate 18*x scale 0.08 }
	finish { phong PHONG specular SPECULAR }
	}
}

#declare Machin_4_full = object
{
#local ee = 0.64;
union	{
	object { Machin_4_a }

	#local H1 = 0.40 + abs(2.00*sin(radians(clock)*4));
	#local H2 = 1.20 + sin(radians(clock)*4.555);
	#local H3 = 1.80 + 0.40 * (rand(RND)+rand(RND));

	/* les cotés */
	object { Machin_4_une_barre_b(H1) translate <  0, 0, -ee> }
	object { Machin_4_une_barre_a(H1) translate < ee, 0,   0> }
	object { Machin_4_une_barre_a(H1) translate <  0, 0,  ee> }
	object { Machin_4_une_barre_a(H1) translate <-ee, 0,   0> }

	/* les angles */
	object { Machin_4_une_barre_a(H2) translate <-ee, 0, -ee> }
	object { Machin_4_une_barre_a(H2) translate < ee, 0, -ee> }
	object { Machin_4_une_barre_b(H2) translate <-ee, 0,  ee> }
	object { Machin_4_une_barre_a(H2) translate < ee, 0,  ee> }

	object { Machin_4_une_barre_a(H3) rotate y*45 }
	}
rotate y*1.414
}

#declare Le_Machin_neuf_barres = object
{
union {
	object { Machin_4_full translate y*H_base }
	object { Base_Machins }
	}
}

// ----------------------------------------------------------
/*
 *		un enpilement de disques troués
 */
#local Bas  = 0.000;
#local Haut = 2.900;

#declare Machin_5_a = object
{
#local da = 0.018;
#local db = da + 0.05;
merge {
	box { <-da, Bas, -db>, <da, Haut, db> }
	box { <-db, Bas, -da>, <db, Haut, da> }
	}
}

#declare Machin_5_montants = object
{
#local ee = 0.422;
union	{
	object { Machin_5_a rotate y*45 translate <-ee, 0, -ee> }
	object { Machin_5_a rotate y*45 translate < ee, 0, -ee> }
	object { Machin_5_a rotate y*45 translate <-ee, 0,  ee> }
	object { Machin_5_a rotate y*45 translate < ee, 0,  ee> }
	}
texture {
	pigment { color rgb <0.50, 0.40, 0.39> }
	finish { phong PHONG specular SPECULAR }
	}
}

#declare Machin_5_disques = object
{
union	{
#for (foo, Bas+0.25, Haut, 0.410)
	difference {
		sphere { <0, 0, 0>, 0.069 scale <11, 1, 12> }
		cylinder { <0, -1, 0>, <0, 1, 0>, 0.44 }
		rotate    y*(foo*60)
		translate y*foo
		}
#end
	}
texture {
  pigment {
    gradient y
      color_map {
	  [ 0.0  color Orange		]
	  [ 0.3  color Gray50		]
	  [ 0.5  color Blue		]
	  [ 0.7  color Gray50		]
	  [ 1.0  color Orange		]
        }
	turbulence 0.70		/* clock dependant maybe */
    	scale 0.35
	rotate clock*0.33333333
    }
	finish { phong PHONG specular SPECULAR }
	}
}

#declare Machin_5 = object
{
union	{
	object { Machin_5_montants }
	object { Machin_5_disques }
	}
}

#declare Le_Machin_Disques = object
{
union {
	object { Machin_5 translate y*H_base }
	object { Base_Machins }
	}
}

/*    ======================================================    */

#local E = 0.56;
#local R = 0.21;

#declare Machin_6_tube = object
{
#local e2 = E - 0.20;
#local r2 = R * 0.33;
merge	{
	cylinder { <-e2, 0, 0>, <e2, 0, 0>, r2 }
	sphere   { < e2, 0, 0>, r2 }
	sphere   { <-e2, 0, 0>, r2 }
	}
#undef e2
#undef r2
}

#declare Machin_6_les_tubes = object
{
union	{
#for (foo, 0, 360, 45)
	#local et = 0.43;
	#local dy = et * cos(radians(foo));
	#local dz = et * sin(radians(foo));
	object { Machin_6_tube translate <0, dy, dz> }
	#local et = 0.60;
	#local dy = et * cos(radians(foo)+0.29);
	#local dz = et * sin(radians(foo)+0.29);
	object { Machin_6_tube scale 0.65 translate <0, dy, dz> }
#end
	}
texture {
	pigment { color Orange }
	finish { phong PHONG specular SPECULAR }
	}
rotate x*(clock*clock)
}

// ----------------------------------------------------------
/* sur l'axe de rotation */

#declare Machin_6_moyeu = object
{
difference {
	#local e2 = E + 0.1;
	cylinder { <-E, 0, 0>, <E, 0, 0>, R }
	cylinder { <-e2, 0, 0>, <e2, 0, 0>, R*0.777 }
	box { <-0.42, -0.14, -10>, <-0.10, 0.14, 10> }
	box { < 0.42, -0.14, -10>, < 0.10, 0.14, 10> }
	#undef e2
	}
texture {
	pigment { color Gray60 }
	normal { bumps 0.25 scale 0.15 }
	finish { phong PHONG specular SPECULAR }
	}
rotate x*(clock*7.777)
}

#local hh = 0.96;

// ----------------------------------------------------------

#declare machin_6_palier = object
{
#local SP = 0.05;
#local RP = R*0.25;
union	{
	cylinder { <-SP , 0, 0>, <SP , 0, 0>,		RP }
	sphere   { 0, RP scale <0.5, 1, 1> translate -x*SP }
	sphere   { 0, RP scale <0.5, 1, 1> translate  x*SP }
	}
#undef SP
}

#declare M6_support_a = object
{
merge	{
	// cylinder { <-0.05, hh, 0>, <0.05, hh, 0>, 0.07 	}
	object { machin_6_palier translate y*hh			}
	box { <-0.08, 0, -0.70>,   < 0.08, 0.03,  0.70>		}
	cylinder { <0, 0, -0.50>, <0, hh, 0>, 0.030 }
	cylinder { <0, 0,  0.50>, <0, hh, 0>, 0.030 }
	}
texture {
	pigment { color rgb <0.70, 0.20, 0.20> }
	finish { phong PHONG specular SPECULAR }
	}
}

#declare M6_axe = object
{
#local e2 = E+0.22;

cylinder { <-e2, 0, 0>, <e2, 0, 0>, 0.03 }
texture {
	pigment { color rgb <0.020, 0.070, 0.030>  }
	finish { phong PHONG specular SPECULAR }
	}
#undef e2
}

#declare M6_Support = object
{
union	{
	object { M6_support_a   translate -0.68*x 	}
	object { M6_axe		translate  hh*y		}
	object { M6_support_a   translate  0.68*x 	}
	}
}

// ----------------------------------------------------------

#declare Machin_6 = object
{
union {
	#local h2 = hh + H_base;
	object { Machin_6_les_tubes  translate y*hh    }
	object { Machin_6_moyeu      translate y*hh    }
	object { M6_Support              }
	}
}

#declare Le_Machin_6 = object
{
union {
	object { Machin_6           translate y*H_base }
	object { Base_Machins }
	object { Lampe_Cube rotate z*20 translate <-0.73, 3.5, -0.05> }
	}
}

/*    ======================================================    */


#local R1_m7 = 0.67;
#local R2_m7 = 0.25;

#declare Machin_7_tube = object 
{
difference {
	torus { R1_m7, R2_m7 }
	torus { R1_m7, R2_m7-0.02 }
	}
}

#declare Machin_7_tore_complet = object 
{
difference {
	object { Machin_7_tube }
	#for (foo, 0, 360, 32.727272)
	  cylinder {
		<1, 0, 0>, <0.75, 0, 0>, 0.11
		scale <1, 1, 1.42>
		rotate y*foo
		}
	#end 
	}
texture { T_Brass_4B }
}

#declare Machin_7_trucs_qui_tourne = object
{
#local Kfsp = 0.160;
#local Offs = 1.210;
union	{
	#local Px = R1_m7 * sin(clock*Kfsp);
	#local Pz = R1_m7 * cos(clock*Kfsp);
	sphere  {
		<0, 0, 0>, R2_m7*0.60
		translate <Px, 0, Pz> 
		texture { pigment { color Red } finish {  emission 0.70 } }
		}
	#local Px = R1_m7 * sin((clock*Kfsp)+Offs);
	#local Pz = R1_m7 * cos((clock*Kfsp)+Offs);
	sphere  { <0, 0, 0>, R2_m7*0.60
		translate <Px, 0, Pz>	
		texture { pigment { color Green } finish {  emission 0.70 } }
		}
	#local Px = R1_m7 * sin((clock*Kfsp)+(2*Offs));
	#local Pz = R1_m7 * cos((clock*Kfsp)+(2*Offs));
	sphere  { <0, 0, 0>, R2_m7*0.60
		translate <Px, 0, Pz>	
		texture { pigment { color Blue } finish {  emission 0.70 } }
		}
	}
}	

#declare Machin_7 = object
{
union	{
	object { Machin_7_tore_complet }
	object { Machin_7_trucs_qui_tourne }
	}
rotate x*7
rotate y * (clock/9.87)
}

#declare Le_Machin_7 = object
{
union {
	object { Base_Trucs						}
	object { Machin_7	 translate y*(0.75+H_base)		}
	object { Lampe_Cube rotate x*97	translate <0, 1.30, 2.90> 		}
	}
}

/*    ======================================================    */

/*
 *	nouveau : Mon 02 Jan 2023 01:11:33 PM CET
 */
#declare Machin_8_element_a = object
{
#local sX = 0.351;
#local sZ = 0.076;
  box { <-sX, 0, -sZ>, <sX, 0.045, sZ> }
  texture { GRIS_BROTCH scale 1.111 }
#undef sX
#undef sZ
}
#declare Machin_8_element_b = object
{
#local sX = 0.351;
#local sZ = 0.026;
box { <-sX, 0, -sZ>, <sX, 0.045, 0.07> }
texture { MON_VERT_INDUS scale 0.210 }
#undef sX
#undef sZ
}

#declare Machin_8_spirale = object
{
union	{
	#for (foo, 0, 36)
	  #local dY = 0.083*foo;
	  #local rY = foo*13.20;
	  object { Machin_8_element_a
			translate -z*0.70
			rotate y*rY
			translate y*dY }
	  object { Machin_8_element_b
			translate z*(-0.12+1.3*Cos_010(NormClock))
			rotate y*rY
			translate y*dY 				}
	#end
	}
}

#declare Le_Machin_Spiraleux = object
{
union {
	object { Base_Ronde_Pieds				}
	object { Machin_8_spirale translate y*(0.08+H_base)	}
	object { Lampe_Boule_avec_support rotate y*33.3333	}
	}
}


/*    ======================================================    */

/* un cactus un peu étrange */

#declare Poteau_Coin_tronc = object
{
#local DP = 0.27;
#local HP = 5.27;
#local D2 = DP * 0.60;

merge {
	//
	cone { <0, 0, 0>, DP, <0, HP, 0>, D2 }
	sphere { <0, 0, 0>, D2 scale <1, 0.65, 1> translate y*HP }
	//
	cone { <0, 0.2, 0>, DP*3.15, <0, 0.35, 0>, DP }
	cylinder { <0, 0, 0>, <0, 0.2, 0>, DP*3.15 }
	//
	}
}

/* les branches du pseudo cactus */
#declare Poteau_Coin_b = object
{
merge {
	#local E2 = DP * 2.94;
	#local E3 = E2 * 1.22;		// * incline les branches
	#local D2 = DP * 0.41;
	cylinder { <0, 0, 0>, <E2, 0, 0>, D2 }
	sphere { <E2, 0.00, 0>, D2 }
	cylinder { <E2, 0, 0>, <E3, 0.60, 0>, D2 }
	sphere { <E3, 0.60, 0>, D2 }
	}
}

#declare Poteau_Cactus = object
{
merge	{
	object { Poteau_Coin_tronc }
	object { Poteau_Coin_b rotate y*17   translate y*3.9   }
	object { Poteau_Coin_b rotate y*110  translate y*3.3   }
	object { Poteau_Coin_b rotate y*230  translate y*2.7   }
	object { Poteau_Coin_b rotate y*297  translate y*2.1   }
	}
texture {
	pigment { color Orange }
	normal { bumps 0.20 rotate 9 scale <0.08, 0.04, 0.09> }
	finish { phong PHONG  specular SPECULAR reflection 0.02 }
	}

}
// ----------------------------------------------------------
